# Changelog

## 1.0.2 (2025-05-26)

Full Changelog: [v1.0.1...v1.0.2](https://github.com/natecobb/medici-client/compare/v1.0.1...v1.0.2)

### Chores

* update SDK settings ([13f6211](https://github.com/natecobb/medici-client/commit/13f6211127266f94dd93e7450f653ed41a4d4785))

## 1.0.1 (2025-05-26)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/natecobb/medici-client/compare/v1.0.0...v1.0.1)

### Chores

* **internal:** version bump ([f41bd67](https://github.com/natecobb/medici-client/commit/f41bd671436a5fd7415b8c21864200ca2b99914d))

## 1.0.0 (2025-05-26)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/natecobb/medici-client/compare/v0.0.1-alpha.0...v1.0.0)

### Features

* **api:** update via SDK Studio ([565d0ae](https://github.com/natecobb/medici-client/commit/565d0ae6c4593745437b72acf844f5df4c3eb07d))


### Chores

* update SDK settings ([e1e2a6d](https://github.com/natecobb/medici-client/commit/e1e2a6dfedc40c9b492b1d0d85378003741ace9b))
* update SDK settings ([b69c2d0](https://github.com/natecobb/medici-client/commit/b69c2d061ec14d9b71fa743cb38e85a9c9e1e4c8))
